diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/dispatcher/dsmethod.c acpica-unix-20050902/drivers/acpi/dispatcher/dsmethod.c
--- acpica-unix-20050815/drivers/acpi/dispatcher/dsmethod.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/dispatcher/dsmethod.c	2005-09-02 23:37:11.000000000 -0400
@@ -207,6 +207,13 @@
 		return_ACPI_STATUS(AE_NULL_ENTRY);
 	}
 
+	/* Prevent wraparound of thread count */
+
+	if (obj_desc->method.thread_count == ACPI_UINT8_MAX) {
+		ACPI_REPORT_ERROR(("Method reached maximum reentrancy limit (255)\n"));
+		return_ACPI_STATUS(AE_AML_METHOD_LIMIT);
+	}
+
 	/*
 	 * If there is a concurrency limit on this method, we need to
 	 * obtain a unit from the method semaphore.
@@ -237,6 +244,18 @@
 	}
 
 	/*
+	 * Allocate an Owner ID for this method, only if this is the first thread
+	 * to begin concurrent execution. We only need one owner_id, even if the
+	 * method is invoked recursively.
+	 */
+	if (!obj_desc->method.owner_id) {
+		status = acpi_ut_allocate_owner_id(&obj_desc->method.owner_id);
+		if (ACPI_FAILURE(status)) {
+			return_ACPI_STATUS(status);
+		}
+	}
+
+	/*
 	 * Increment the method parse tree thread count since it has been
 	 * reentered one more time (even if it is the same thread)
 	 */
@@ -289,11 +308,6 @@
 		return_ACPI_STATUS(AE_NULL_OBJECT);
 	}
 
-	status = acpi_ut_allocate_owner_id(&obj_desc->method.owner_id);
-	if (ACPI_FAILURE(status)) {
-		return_ACPI_STATUS(status);
-	}
-
 	/* Init for new method, wait on concurrency semaphore */
 
 	status = acpi_ds_begin_method_execution(method_node, obj_desc,
@@ -345,9 +359,8 @@
 	}
 	/*
 	 * The resolved arguments were put on the previous walk state's operand
-	 * stack.  Operands on the previous walk state stack always
-	 * start at index 0.
-	 * Null terminate the list of arguments
+	 * stack. Operands on the previous walk state stack always
+	 * start at index 0. Also, null terminate the list of arguments
 	 */
 	this_walk_state->operands[this_walk_state->num_operands] = NULL;
 
@@ -380,21 +393,20 @@
 
 	if (obj_desc->method.method_flags & AML_METHOD_INTERNAL_ONLY) {
 		status = obj_desc->method.implementation(next_walk_state);
-		return_ACPI_STATUS(status);
 	}
 
-	return_ACPI_STATUS(AE_OK);
-
-	/* On error, we must delete the new walk state */
+	return_ACPI_STATUS(status);
 
       cleanup:
-	acpi_ut_release_owner_id(&obj_desc->method.owner_id);
-	if (next_walk_state && (next_walk_state->method_desc)) {
-		/* Decrement the thread count on the method parse tree */
+	/* Decrement the thread count on the method parse tree */
 
+	if (next_walk_state && (next_walk_state->method_desc)) {
 		next_walk_state->method_desc->method.thread_count--;
 	}
-	(void)acpi_ds_terminate_control_method(next_walk_state);
+
+	/* On error, we must delete the new walk state */
+
+	acpi_ds_terminate_control_method(next_walk_state);
 	acpi_ds_delete_walk_state(next_walk_state);
 	return_ACPI_STATUS(status);
 }
@@ -479,7 +491,7 @@
  *
  * PARAMETERS:  walk_state          - State of the method
  *
- * RETURN:      Status
+ * RETURN:      None
  *
  * DESCRIPTION: Terminate a control method.  Delete everything that the method
  *              created, delete all locals and arguments, and delete the parse
@@ -487,7 +499,7 @@
  *
  ******************************************************************************/
 
-acpi_status acpi_ds_terminate_control_method(struct acpi_walk_state *walk_state)
+void acpi_ds_terminate_control_method(struct acpi_walk_state *walk_state)
 {
 	union acpi_operand_object *obj_desc;
 	struct acpi_namespace_node *method_node;
@@ -496,14 +508,14 @@
 	ACPI_FUNCTION_TRACE_PTR("ds_terminate_control_method", walk_state);
 
 	if (!walk_state) {
-		return (AE_BAD_PARAMETER);
+		return_VOID;
 	}
 
 	/* The current method object was saved in the walk state */
 
 	obj_desc = walk_state->method_desc;
 	if (!obj_desc) {
-		return_ACPI_STATUS(AE_OK);
+		return_VOID;
 	}
 
 	/* Delete all arguments and locals */
@@ -517,7 +529,7 @@
 	 */
 	status = acpi_ut_acquire_mutex(ACPI_MTX_PARSER);
 	if (ACPI_FAILURE(status)) {
-		return_ACPI_STATUS(status);
+		return_VOID;
 	}
 
 	/* Signal completion of the execution of this method if necessary */
@@ -528,7 +540,6 @@
 					     semaphore, 1);
 		if (ACPI_FAILURE(status)) {
 			ACPI_REPORT_ERROR(("Could not signal method semaphore\n"));
-			status = AE_OK;
 
 			/* Ignore error and continue cleanup */
 		}
@@ -539,9 +550,8 @@
 				  "*** Not deleting method namespace, there are still %d threads\n",
 				  walk_state->method_desc->method.
 				  thread_count));
-	}
+	} else {		/* This is the last executing thread */
 
-	if (!walk_state->method_desc->method.thread_count) {
 		/*
 		 * Support to dynamically change a method from not_serialized to
 		 * Serialized if it appears that the method is written foolishly and
@@ -574,7 +584,7 @@
 		 */
 		status = acpi_ut_acquire_mutex(ACPI_MTX_NAMESPACE);
 		if (ACPI_FAILURE(status)) {
-			return_ACPI_STATUS(status);
+			goto exit;
 		}
 
 		if (method_node->child) {
@@ -590,12 +600,9 @@
 		status = acpi_ut_release_mutex(ACPI_MTX_NAMESPACE);
 		acpi_ut_release_owner_id(&walk_state->method_desc->method.
 					 owner_id);
-
-		if (ACPI_FAILURE(status)) {
-			return_ACPI_STATUS(status);
-		}
 	}
 
-	status = acpi_ut_release_mutex(ACPI_MTX_PARSER);
-	return_ACPI_STATUS(status);
+      exit:
+	(void)acpi_ut_release_mutex(ACPI_MTX_PARSER);
+	return_VOID;
 }
diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/dispatcher/dswload.c acpica-unix-20050902/drivers/acpi/dispatcher/dswload.c
--- acpica-unix-20050815/drivers/acpi/dispatcher/dswload.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/dispatcher/dswload.c	2005-09-02 23:37:11.000000000 -0400
@@ -486,8 +486,10 @@
 		if ((!(walk_state->op_info->flags & AML_NSOPCODE) &&
 		     (walk_state->opcode != AML_INT_NAMEPATH_OP)) ||
 		    (!(walk_state->op_info->flags & AML_NAMED))) {
+#ifdef ACPI_ENABLE_MODULE_LEVEL_CODE
 			if ((walk_state->op_info->class == AML_CLASS_EXECUTE) ||
 			    (walk_state->op_info->class == AML_CLASS_CONTROL)) {
+
 				ACPI_DEBUG_PRINT((ACPI_DB_DISPATCH,
 						  "Begin/EXEC: %s (fl %8.8X)\n",
 						  walk_state->op_info->name,
@@ -499,6 +501,7 @@
 				    acpi_ds_exec_begin_op(walk_state, out_op);
 				return_ACPI_STATUS(status);
 			}
+#endif
 			return_ACPI_STATUS(AE_OK);
 		}
 
@@ -731,6 +734,7 @@
 
 	if (!(walk_state->op_info->flags & AML_NSOBJECT)) {
 #ifndef ACPI_NO_METHOD_EXECUTION
+#ifdef ACPI_ENABLE_MODULE_LEVEL_CODE
 		/* No namespace object. Executable opcode? */
 
 		if ((walk_state->op_info->class == AML_CLASS_EXECUTE) ||
@@ -746,6 +750,7 @@
 			return_ACPI_STATUS(status);
 		}
 #endif
+#endif
 		return_ACPI_STATUS(AE_OK);
 	}
 
diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/parser/psparse.c acpica-unix-20050902/drivers/acpi/parser/psparse.c
--- acpica-unix-20050815/drivers/acpi/parser/psparse.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/parser/psparse.c	2005-09-02 23:37:11.000000000 -0400
@@ -438,7 +438,6 @@
 acpi_status acpi_ps_parse_aml(struct acpi_walk_state *walk_state)
 {
 	acpi_status status;
-	acpi_status terminate_status;
 	struct acpi_thread_state *thread;
 	struct acpi_thread_state *prev_walk_list = acpi_gbl_current_walk_list;
 	struct acpi_walk_state *previous_walk_state;
@@ -508,6 +507,10 @@
 						 walk_state->method_node, NULL,
 						 status);
 
+			/* Ensure proper cleanup */
+
+			walk_state->parse_flags |= ACPI_PARSE_EXECUTE;
+
 			/* Check for possible multi-thread reentrancy problem */
 
 			if ((status == AE_ALREADY_EXISTS) &&
@@ -524,14 +527,6 @@
 			}
 		}
 
-		if (walk_state->method_desc) {
-			/* Decrement the thread count on the method parse tree */
-
-			if (walk_state->method_desc->method.thread_count) {
-				walk_state->method_desc->method.thread_count--;
-			}
-		}
-
 		/* We are done with this walk, move on to the parent if any */
 
 		walk_state = acpi_ds_pop_walk_state(thread);
@@ -546,13 +541,13 @@
 		 */
 		if ((walk_state->parse_flags & ACPI_PARSE_MODE_MASK) ==
 		    ACPI_PARSE_EXECUTE) {
-			terminate_status =
-			    acpi_ds_terminate_control_method(walk_state);
-			if (ACPI_FAILURE(terminate_status)) {
-				ACPI_REPORT_ERROR(("Could not terminate control method properly\n"));
+			if (walk_state->method_desc) {
+				/* Decrement the thread count on the method parse tree */
 
-				/* Ignore error and continue */
+				walk_state->method_desc->method.thread_count--;
 			}
+
+			acpi_ds_terminate_control_method(walk_state);
 		}
 
 		/* Delete this walk state and all linked control states */
diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/parser/psxface.c acpica-unix-20050902/drivers/acpi/parser/psxface.c
--- acpica-unix-20050815/drivers/acpi/parser/psxface.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/parser/psxface.c	2005-09-02 23:37:11.000000000 -0400
@@ -99,16 +99,6 @@
 	}
 
 	/*
-	 * Get a new owner_id for objects created by this method. Namespace
-	 * objects (such as Operation Regions) can be created during the
-	 * first pass parse.
-	 */
-	status = acpi_ut_allocate_owner_id(&info->obj_desc->method.owner_id);
-	if (ACPI_FAILURE(status)) {
-		return_ACPI_STATUS(status);
-	}
-
-	/*
 	 * The caller "owns" the parameters, so give each one an extra
 	 * reference
 	 */
@@ -139,10 +129,6 @@
 	status = acpi_ps_execute_pass(info);
 
       cleanup:
-	if (info->obj_desc->method.owner_id) {
-		acpi_ut_release_owner_id(&info->obj_desc->method.owner_id);
-	}
-
 	/* Take away the extra reference that we gave the parameters above */
 
 	acpi_ps_update_parameter_list(info, REF_DECREMENT);
diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/resources/rsaddr.c acpica-unix-20050902/drivers/acpi/resources/rsaddr.c
--- acpica-unix-20050815/drivers/acpi/resources/rsaddr.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/resources/rsaddr.c	2005-09-02 23:37:11.000000000 -0400
@@ -47,6 +47,180 @@
 #define _COMPONENT          ACPI_RESOURCES
 ACPI_MODULE_NAME("rsaddr")
 
+/* Local prototypes */
+static void
+acpi_rs_decode_general_flags(union acpi_resource_data *resource, u8 flags);
+
+static u8 acpi_rs_encode_general_flags(union acpi_resource_data *resource);
+
+static void
+acpi_rs_decode_specific_flags(union acpi_resource_data *resource, u8 flags);
+
+static u8 acpi_rs_encode_specific_flags(union acpi_resource_data *resource);
+
+/*******************************************************************************
+ *
+ * FUNCTION:    acpi_rs_decode_general_flags
+ *
+ * PARAMETERS:  Resource            - Address resource data struct
+ *              Flags               - Actual flag byte
+ *
+ * RETURN:      Decoded flag bits in resource struct
+ *
+ * DESCRIPTION: Decode a general flag byte to an address resource struct
+ *
+ ******************************************************************************/
+
+static void
+acpi_rs_decode_general_flags(union acpi_resource_data *resource, u8 flags)
+{
+	ACPI_FUNCTION_ENTRY();
+
+	/* Producer / Consumer - flag bit[0] */
+
+	resource->address.producer_consumer = (u32) (flags & 0x01);
+
+	/* Decode (_DEC) - flag bit[1] */
+
+	resource->address.decode = (u32) ((flags >> 1) & 0x01);
+
+	/* Min Address Fixed (_MIF) - flag bit[2] */
+
+	resource->address.min_address_fixed = (u32) ((flags >> 2) & 0x01);
+
+	/* Max Address Fixed (_MAF) - flag bit[3] */
+
+	resource->address.max_address_fixed = (u32) ((flags >> 3) & 0x01);
+}
+
+/*******************************************************************************
+ *
+ * FUNCTION:    acpi_rs_encode_general_flags
+ *
+ * PARAMETERS:  Resource            - Address resource data struct
+ *
+ * RETURN:      Encoded general flag byte
+ *
+ * DESCRIPTION: Construct a general flag byte from an address resource struct
+ *
+ ******************************************************************************/
+
+static u8 acpi_rs_encode_general_flags(union acpi_resource_data *resource)
+{
+	u8 flags;
+
+	ACPI_FUNCTION_ENTRY();
+
+	/* Producer / Consumer - flag bit[0] */
+
+	flags = (u8) (resource->address.producer_consumer & 0x01);
+
+	/* Decode (_DEC) - flag bit[1] */
+
+	flags |= (u8) ((resource->address.decode & 0x01) << 1);
+
+	/* Min Address Fixed (_MIF) - flag bit[2] */
+
+	flags |= (u8) ((resource->address.min_address_fixed & 0x01) << 2);
+
+	/* Max Address Fixed (_MAF) - flag bit[3] */
+
+	flags |= (u8) ((resource->address.max_address_fixed & 0x01) << 3);
+
+	return (flags);
+}
+
+/*******************************************************************************
+ *
+ * FUNCTION:    acpi_rs_decode_specific_flags
+ *
+ * PARAMETERS:  Resource            - Address resource data struct
+ *              Flags               - Actual flag byte
+ *
+ * RETURN:      Decoded flag bits in attribute struct
+ *
+ * DESCRIPTION: Decode a type-specific flag byte to an attribute struct.
+ *              Type-specific flags are only defined for the Memory and IO
+ *              resource types.
+ *
+ ******************************************************************************/
+
+static void
+acpi_rs_decode_specific_flags(union acpi_resource_data *resource, u8 flags)
+{
+	ACPI_FUNCTION_ENTRY();
+
+	if (resource->address.resource_type == ACPI_MEMORY_RANGE) {
+		/* Write Status (_RW) - flag bit[0] */
+
+		resource->address.attribute.memory.read_write_attribute =
+		    (u16) (flags & 0x01);
+
+		/* Memory Attributes (_MEM) - flag bits[2:1] */
+
+		resource->address.attribute.memory.cache_attribute =
+		    (u16) ((flags >> 1) & 0x03);
+	} else if (resource->address.resource_type == ACPI_IO_RANGE) {
+		/* Ranges (_RNG) - flag bits[1:0] */
+
+		resource->address.attribute.io.range_attribute =
+		    (u16) (flags & 0x03);
+
+		/* Translations (_TTP and _TRS) - flag bits[5:4] */
+
+		resource->address.attribute.io.translation_attribute =
+		    (u16) ((flags >> 4) & 0x03);
+	}
+}
+
+/*******************************************************************************
+ *
+ * FUNCTION:    acpi_rs_encode_specific_flags
+ *
+ * PARAMETERS:  Resource            - Address resource data struct
+ *
+ * RETURN:      Encoded type-specific flag byte
+ *
+ * DESCRIPTION: Construct a type-specific flag byte from an attribute struct.
+ *              Type-specific flags are only defined for the Memory and IO
+ *              resource types.
+ *
+ ******************************************************************************/
+
+static u8 acpi_rs_encode_specific_flags(union acpi_resource_data *resource)
+{
+	u8 flags = 0;
+
+	ACPI_FUNCTION_ENTRY();
+
+	if (resource->address.resource_type == ACPI_MEMORY_RANGE) {
+		/* Write Status (_RW) - flag bit[0] */
+
+		flags = (u8)
+		    (resource->address.attribute.memory.
+		     read_write_attribute & 0x01);
+
+		/* Memory Attributes (_MEM) - flag bits[2:1] */
+
+		flags |= (u8)
+		    ((resource->address.attribute.memory.
+		      cache_attribute & 0x03) << 1);
+	} else if (resource->address.resource_type == ACPI_IO_RANGE) {
+		/* Ranges (_RNG) - flag bits[1:0] */
+
+		flags = (u8)
+		    (resource->address.attribute.io.range_attribute & 0x03);
+
+		/* Translations (_TTP and _TRS) - flag bits[5:4] */
+
+		flags |= (u8)
+		    ((resource->address.attribute.io.
+		      translation_attribute & 0x03) << 4);
+	}
+
+	return (flags);
+}
+
 /*******************************************************************************
  *
  * FUNCTION:    acpi_rs_address16_resource
@@ -67,6 +241,7 @@
  *              number of bytes consumed from the byte stream.
  *
  ******************************************************************************/
+
 acpi_status
 acpi_rs_address16_resource(u8 * byte_stream_buffer,
 			   acpi_size * bytes_consumed,
@@ -83,7 +258,7 @@
 
 	ACPI_FUNCTION_TRACE("rs_address16_resource");
 
-	/* Point past the Descriptor to get the number of bytes consumed */
+	/* Get the Descriptor Length field */
 
 	buffer += 1;
 	ACPI_MOVE_16_TO_16(&temp16, buffer);
@@ -113,46 +288,12 @@
 	/* Get the General Flags (Byte4) */
 
 	buffer += 1;
-	temp8 = *buffer;
-
-	/* Producer / Consumer */
-
-	output_struct->data.address16.producer_consumer = temp8 & 0x01;
-
-	/* Decode */
-
-	output_struct->data.address16.decode = (temp8 >> 1) & 0x01;
-
-	/* Min Address Fixed */
-
-	output_struct->data.address16.min_address_fixed = (temp8 >> 2) & 0x01;
-
-	/* Max Address Fixed */
-
-	output_struct->data.address16.max_address_fixed = (temp8 >> 3) & 0x01;
+	acpi_rs_decode_general_flags(&output_struct->data, *buffer);
 
 	/* Get the Type Specific Flags (Byte5) */
 
 	buffer += 1;
-	temp8 = *buffer;
-
-	if (ACPI_MEMORY_RANGE == output_struct->data.address16.resource_type) {
-		output_struct->data.address16.attribute.memory.
-		    read_write_attribute = (u16) (temp8 & 0x01);
-		output_struct->data.address16.attribute.memory.cache_attribute =
-		    (u16) ((temp8 >> 1) & 0x03);
-	} else {
-		if (ACPI_IO_RANGE ==
-		    output_struct->data.address16.resource_type) {
-			output_struct->data.address16.attribute.io.
-			    range_attribute = (u16) (temp8 & 0x03);
-			output_struct->data.address16.attribute.io.
-			    translation_attribute = (u16) ((temp8 >> 4) & 0x03);
-		} else {
-			/* BUS_NUMBER_RANGE == Address16.Data->resource_type */
-			/* Nothing needs to be filled in */
-		}
-	}
+	acpi_rs_decode_specific_flags(&output_struct->data, *buffer);
 
 	/* Get Granularity (Bytes 6-7) */
 
@@ -200,9 +341,8 @@
 	if (*bytes_consumed > (16 + 1)) {
 		/* Dereference the Index */
 
-		temp8 = *buffer;
 		output_struct->data.address16.resource_source.index =
-		    (u32) temp8;
+		    (u32) * buffer;
 
 		/* Point to the String */
 
@@ -216,22 +356,20 @@
 		temp_ptr = (u8 *)
 		    output_struct->data.address16.resource_source.string_ptr;
 
-		/* Copy the string into the buffer */
+		/* Copy the resource_source string into the buffer */
 
 		index = 0;
-
-		while (0x00 != *buffer) {
+		while (*buffer) {
 			*temp_ptr = *buffer;
 
-			temp_ptr += 1;
-			buffer += 1;
-			index += 1;
+			temp_ptr++;
+			buffer++;
+			index++;
 		}
 
-		/* Add the terminating null */
-
-		*temp_ptr = 0x00;
+		/* Add the terminating null and set the string length */
 
+		*temp_ptr = 0;
 		output_struct->data.address16.resource_source.string_length =
 		    index + 1;
 
@@ -243,7 +381,7 @@
 		temp8 = (u8) (index + 1);
 		struct_size += ACPI_ROUND_UP_to_32_bITS(temp8);
 	} else {
-		output_struct->data.address16.resource_source.index = 0x00;
+		output_struct->data.address16.resource_source.index = 0;
 		output_struct->data.address16.resource_source.string_length = 0;
 		output_struct->data.address16.resource_source.string_ptr = NULL;
 	}
@@ -280,15 +418,13 @@
 {
 	u8 *buffer = *output_buffer;
 	u8 *length_field;
-	u8 temp8;
-	char *temp_pointer = NULL;
 	acpi_size actual_bytes;
 
 	ACPI_FUNCTION_TRACE("rs_address16_stream");
 
-	/* The descriptor field is static */
+	/* Set the Descriptor Type field */
 
-	*buffer = 0x88;
+	*buffer = ACPI_RDESC_TYPE_WORD_ADDRESS_SPACE;
 	buffer += 1;
 
 	/* Save a pointer to the Length field - to be filled in later */
@@ -298,43 +434,17 @@
 
 	/* Set the Resource Type (Memory, Io, bus_number) */
 
-	temp8 = (u8) (linked_list->data.address16.resource_type & 0x03);
-	*buffer = temp8;
+	*buffer = (u8) (linked_list->data.address16.resource_type & 0x03);
 	buffer += 1;
 
 	/* Set the general flags */
 
-	temp8 = (u8) (linked_list->data.address16.producer_consumer & 0x01);
-
-	temp8 |= (linked_list->data.address16.decode & 0x01) << 1;
-	temp8 |= (linked_list->data.address16.min_address_fixed & 0x01) << 2;
-	temp8 |= (linked_list->data.address16.max_address_fixed & 0x01) << 3;
-
-	*buffer = temp8;
+	*buffer = acpi_rs_encode_general_flags(&linked_list->data);
 	buffer += 1;
 
 	/* Set the type specific flags */
 
-	temp8 = 0;
-
-	if (ACPI_MEMORY_RANGE == linked_list->data.address16.resource_type) {
-		temp8 = (u8)
-		    (linked_list->data.address16.attribute.memory.
-		     read_write_attribute & 0x01);
-
-		temp8 |=
-		    (linked_list->data.address16.attribute.memory.
-		     cache_attribute & 0x03) << 1;
-	} else if (ACPI_IO_RANGE == linked_list->data.address16.resource_type) {
-		temp8 = (u8)
-		    (linked_list->data.address16.attribute.io.range_attribute &
-		     0x03);
-		temp8 |=
-		    (linked_list->data.address16.attribute.io.
-		     translation_attribute & 0x03) << 4;
-	}
-
-	*buffer = temp8;
+	*buffer = acpi_rs_encode_specific_flags(&linked_list->data);
 	buffer += 1;
 
 	/* Set the address space granularity */
@@ -368,22 +478,19 @@
 
 	/* Resource Source Index and Resource Source are optional */
 
-	if (0 != linked_list->data.address16.resource_source.string_length) {
-		temp8 = (u8) linked_list->data.address16.resource_source.index;
-
-		*buffer = temp8;
+	if (linked_list->data.address16.resource_source.string_length) {
+		*buffer =
+		    (u8) linked_list->data.address16.resource_source.index;
 		buffer += 1;
 
-		temp_pointer = (char *)buffer;
-
-		/* Copy the string */
+		/* Copy the resource_source string */
 
-		ACPI_STRCPY(temp_pointer,
+		ACPI_STRCPY((char *)buffer,
 			    linked_list->data.address16.resource_source.
 			    string_ptr);
 
 		/*
-		 * Buffer needs to be set to the length of the sting + one for the
+		 * Buffer needs to be set to the length of the string + one for the
 		 * terminating null
 		 */
 		buffer +=
@@ -432,20 +539,18 @@
 			   acpi_size * bytes_consumed,
 			   u8 ** output_buffer, acpi_size * structure_size)
 {
-	u8 *buffer;
-	struct acpi_resource *output_struct = (void *)*output_buffer;
 	u16 temp16;
 	u8 temp8;
 	u8 *temp_ptr;
-	acpi_size struct_size;
 	u32 index;
+	u8 *buffer = byte_stream_buffer;
+	struct acpi_resource *output_struct = (void *)*output_buffer;
+	acpi_size struct_size =
+	    ACPI_SIZEOF_RESOURCE(struct acpi_resource_address32);
 
 	ACPI_FUNCTION_TRACE("rs_address32_resource");
 
-	buffer = byte_stream_buffer;
-	struct_size = ACPI_SIZEOF_RESOURCE(struct acpi_resource_address32);
-
-	/* Point past the Descriptor to get the number of bytes consumed */
+	/* Get the Descriptor Length field */
 
 	buffer += 1;
 	ACPI_MOVE_16_TO_16(&temp16, buffer);
@@ -475,47 +580,12 @@
 	/* Get the General Flags (Byte4) */
 
 	buffer += 1;
-	temp8 = *buffer;
-
-	/* Producer / Consumer */
-
-	output_struct->data.address32.producer_consumer = temp8 & 0x01;
-
-	/* Decode */
-
-	output_struct->data.address32.decode = (temp8 >> 1) & 0x01;
-
-	/* Min Address Fixed */
-
-	output_struct->data.address32.min_address_fixed = (temp8 >> 2) & 0x01;
-
-	/* Max Address Fixed */
-
-	output_struct->data.address32.max_address_fixed = (temp8 >> 3) & 0x01;
+	acpi_rs_decode_general_flags(&output_struct->data, *buffer);
 
 	/* Get the Type Specific Flags (Byte5) */
 
 	buffer += 1;
-	temp8 = *buffer;
-
-	if (ACPI_MEMORY_RANGE == output_struct->data.address32.resource_type) {
-		output_struct->data.address32.attribute.memory.
-		    read_write_attribute = (u16) (temp8 & 0x01);
-
-		output_struct->data.address32.attribute.memory.cache_attribute =
-		    (u16) ((temp8 >> 1) & 0x03);
-	} else {
-		if (ACPI_IO_RANGE ==
-		    output_struct->data.address32.resource_type) {
-			output_struct->data.address32.attribute.io.
-			    range_attribute = (u16) (temp8 & 0x03);
-			output_struct->data.address32.attribute.io.
-			    translation_attribute = (u16) ((temp8 >> 4) & 0x03);
-		} else {
-			/* BUS_NUMBER_RANGE == output_struct->Data.Address32.resource_type */
-			/* Nothing needs to be filled in */
-		}
-	}
+	acpi_rs_decode_specific_flags(&output_struct->data, *buffer);
 
 	/* Get Granularity (Bytes 6-9) */
 
@@ -561,9 +631,8 @@
 	if (*bytes_consumed > (26 + 1)) {
 		/* Dereference the Index */
 
-		temp8 = *buffer;
 		output_struct->data.address32.resource_source.index =
-		    (u32) temp8;
+		    (u32) * buffer;
 
 		/* Point to the String */
 
@@ -577,20 +646,20 @@
 		temp_ptr = (u8 *)
 		    output_struct->data.address32.resource_source.string_ptr;
 
-		/* Copy the string into the buffer */
+		/* Copy the resource_source string into the buffer */
 
 		index = 0;
-		while (0x00 != *buffer) {
+		while (*buffer) {
 			*temp_ptr = *buffer;
 
-			temp_ptr += 1;
-			buffer += 1;
-			index += 1;
+			temp_ptr++;
+			buffer++;
+			index++;
 		}
 
-		/* Add the terminating null */
+		/* Add the terminating null and set the string length */
 
-		*temp_ptr = 0x00;
+		*temp_ptr = 0;
 		output_struct->data.address32.resource_source.string_length =
 		    index + 1;
 
@@ -602,7 +671,7 @@
 		temp8 = (u8) (index + 1);
 		struct_size += ACPI_ROUND_UP_to_32_bITS(temp8);
 	} else {
-		output_struct->data.address32.resource_source.index = 0x00;
+		output_struct->data.address32.resource_source.index = 0;
 		output_struct->data.address32.resource_source.string_length = 0;
 		output_struct->data.address32.resource_source.string_ptr = NULL;
 	}
@@ -639,62 +708,34 @@
 {
 	u8 *buffer;
 	u16 *length_field;
-	u8 temp8;
-	char *temp_pointer;
 
 	ACPI_FUNCTION_TRACE("rs_address32_stream");
 
 	buffer = *output_buffer;
 
-	/* The descriptor field is static */
+	/* Set the Descriptor Type field */
 
-	*buffer = 0x87;
+	*buffer = ACPI_RDESC_TYPE_DWORD_ADDRESS_SPACE;
 	buffer += 1;
 
-	/* Set a pointer to the Length field - to be filled in later */
+	/* Save a pointer to the Length field - to be filled in later */
 
 	length_field = ACPI_CAST_PTR(u16, buffer);
 	buffer += 2;
 
 	/* Set the Resource Type (Memory, Io, bus_number) */
 
-	temp8 = (u8) (linked_list->data.address32.resource_type & 0x03);
-
-	*buffer = temp8;
+	*buffer = (u8) (linked_list->data.address32.resource_type & 0x03);
 	buffer += 1;
 
 	/* Set the general flags */
 
-	temp8 = (u8) (linked_list->data.address32.producer_consumer & 0x01);
-	temp8 |= (linked_list->data.address32.decode & 0x01) << 1;
-	temp8 |= (linked_list->data.address32.min_address_fixed & 0x01) << 2;
-	temp8 |= (linked_list->data.address32.max_address_fixed & 0x01) << 3;
-
-	*buffer = temp8;
+	*buffer = acpi_rs_encode_general_flags(&linked_list->data);
 	buffer += 1;
 
 	/* Set the type specific flags */
 
-	temp8 = 0;
-
-	if (ACPI_MEMORY_RANGE == linked_list->data.address32.resource_type) {
-		temp8 = (u8)
-		    (linked_list->data.address32.attribute.memory.
-		     read_write_attribute & 0x01);
-
-		temp8 |=
-		    (linked_list->data.address32.attribute.memory.
-		     cache_attribute & 0x03) << 1;
-	} else if (ACPI_IO_RANGE == linked_list->data.address32.resource_type) {
-		temp8 = (u8)
-		    (linked_list->data.address32.attribute.io.range_attribute &
-		     0x03);
-		temp8 |=
-		    (linked_list->data.address32.attribute.io.
-		     translation_attribute & 0x03) << 4;
-	}
-
-	*buffer = temp8;
+	*buffer = acpi_rs_encode_specific_flags(&linked_list->data);
 	buffer += 1;
 
 	/* Set the address space granularity */
@@ -728,22 +769,19 @@
 
 	/* Resource Source Index and Resource Source are optional */
 
-	if (0 != linked_list->data.address32.resource_source.string_length) {
-		temp8 = (u8) linked_list->data.address32.resource_source.index;
-
-		*buffer = temp8;
+	if (linked_list->data.address32.resource_source.string_length) {
+		*buffer =
+		    (u8) linked_list->data.address32.resource_source.index;
 		buffer += 1;
 
-		temp_pointer = (char *)buffer;
-
-		/* Copy the string */
+		/* Copy the resource_source string */
 
-		ACPI_STRCPY(temp_pointer,
+		ACPI_STRCPY((char *)buffer,
 			    linked_list->data.address32.resource_source.
 			    string_ptr);
 
 		/*
-		 * Buffer needs to be set to the length of the sting + one for the
+		 * Buffer needs to be set to the length of the string + one for the
 		 *  terminating null
 		 */
 		buffer +=
@@ -758,7 +796,7 @@
 
 	/*
 	 * Set the length field to the number of bytes consumed
-	 *  minus the header size (3 bytes)
+	 * minus the header size (3 bytes)
 	 */
 	*length_field = (u16) (*bytes_consumed - 3);
 	return_ACPI_STATUS(AE_OK);
@@ -790,22 +828,23 @@
 			   acpi_size * bytes_consumed,
 			   u8 ** output_buffer, acpi_size * structure_size)
 {
-	u8 *buffer;
-	struct acpi_resource *output_struct = (void *)*output_buffer;
 	u16 temp16;
 	u8 temp8;
 	u8 resource_type;
 	u8 *temp_ptr;
-	acpi_size struct_size;
 	u32 index;
+	u8 *buffer = byte_stream_buffer;
+	struct acpi_resource *output_struct = (void *)*output_buffer;
+	acpi_size struct_size =
+	    ACPI_SIZEOF_RESOURCE(struct acpi_resource_address64);
 
 	ACPI_FUNCTION_TRACE("rs_address64_resource");
 
-	buffer = byte_stream_buffer;
-	struct_size = ACPI_SIZEOF_RESOURCE(struct acpi_resource_address64);
+	/* Get the Descriptor Type */
+
 	resource_type = *buffer;
 
-	/* Point past the Descriptor to get the number of bytes consumed */
+	/* Get the Descriptor Length field */
 
 	buffer += 1;
 	ACPI_MOVE_16_TO_16(&temp16, buffer);
@@ -835,47 +874,12 @@
 	/* Get the General Flags (Byte4) */
 
 	buffer += 1;
-	temp8 = *buffer;
-
-	/* Producer / Consumer */
-
-	output_struct->data.address64.producer_consumer = temp8 & 0x01;
-
-	/* Decode */
-
-	output_struct->data.address64.decode = (temp8 >> 1) & 0x01;
-
-	/* Min Address Fixed */
-
-	output_struct->data.address64.min_address_fixed = (temp8 >> 2) & 0x01;
-
-	/* Max Address Fixed */
-
-	output_struct->data.address64.max_address_fixed = (temp8 >> 3) & 0x01;
+	acpi_rs_decode_general_flags(&output_struct->data, *buffer);
 
 	/* Get the Type Specific Flags (Byte5) */
 
 	buffer += 1;
-	temp8 = *buffer;
-
-	if (ACPI_MEMORY_RANGE == output_struct->data.address64.resource_type) {
-		output_struct->data.address64.attribute.memory.
-		    read_write_attribute = (u16) (temp8 & 0x01);
-
-		output_struct->data.address64.attribute.memory.cache_attribute =
-		    (u16) ((temp8 >> 1) & 0x03);
-	} else {
-		if (ACPI_IO_RANGE ==
-		    output_struct->data.address64.resource_type) {
-			output_struct->data.address64.attribute.io.
-			    range_attribute = (u16) (temp8 & 0x03);
-			output_struct->data.address64.attribute.io.
-			    translation_attribute = (u16) ((temp8 >> 4) & 0x03);
-		} else {
-			/* BUS_NUMBER_RANGE == output_struct->Data.Address64.resource_type */
-			/* Nothing needs to be filled in */
-		}
-	}
+	acpi_rs_decode_specific_flags(&output_struct->data, *buffer);
 
 	if (resource_type == ACPI_RDESC_TYPE_EXTENDED_ADDRESS_SPACE) {
 		/* Move past revision_id and Reserved byte */
@@ -912,7 +916,7 @@
 	ACPI_MOVE_64_TO_64(&output_struct->data.address64.address_length,
 			   buffer);
 
-	output_struct->data.address64.resource_source.index = 0x00;
+	output_struct->data.address64.resource_source.index = 0;
 	output_struct->data.address64.resource_source.string_length = 0;
 	output_struct->data.address64.resource_source.string_ptr = NULL;
 
@@ -942,9 +946,8 @@
 		if (*bytes_consumed > (46 + 1)) {
 			/* Dereference the Index */
 
-			temp8 = *buffer;
 			output_struct->data.address64.resource_source.index =
-			    (u32) temp8;
+			    (u32) * buffer;
 
 			/* Point to the String */
 
@@ -960,21 +963,21 @@
 			    output_struct->data.address64.resource_source.
 			    string_ptr;
 
-			/* Copy the string into the buffer */
+			/* Copy the resource_source string into the buffer */
 
 			index = 0;
-			while (0x00 != *buffer) {
+			while (*buffer) {
 				*temp_ptr = *buffer;
 
-				temp_ptr += 1;
-				buffer += 1;
-				index += 1;
+				temp_ptr++;
+				buffer++;
+				index++;
 			}
 
 			/*
-			 * Add the terminating null
+			 * Add the terminating null and set the string length
 			 */
-			*temp_ptr = 0x00;
+			*temp_ptr = 0;
 			output_struct->data.address64.resource_source.
 			    string_length = index + 1;
 
@@ -1020,62 +1023,34 @@
 {
 	u8 *buffer;
 	u16 *length_field;
-	u8 temp8;
-	char *temp_pointer;
 
 	ACPI_FUNCTION_TRACE("rs_address64_stream");
 
 	buffer = *output_buffer;
 
-	/* The descriptor field is static */
+	/* Set the Descriptor Type field */
 
-	*buffer = 0x8A;
+	*buffer = ACPI_RDESC_TYPE_QWORD_ADDRESS_SPACE;
 	buffer += 1;
 
-	/* Set a pointer to the Length field - to be filled in later */
+	/* Save a pointer to the Length field - to be filled in later */
 
 	length_field = ACPI_CAST_PTR(u16, buffer);
 	buffer += 2;
 
 	/* Set the Resource Type (Memory, Io, bus_number) */
 
-	temp8 = (u8) (linked_list->data.address64.resource_type & 0x03);
-
-	*buffer = temp8;
+	*buffer = (u8) (linked_list->data.address64.resource_type & 0x03);
 	buffer += 1;
 
 	/* Set the general flags */
 
-	temp8 = (u8) (linked_list->data.address64.producer_consumer & 0x01);
-	temp8 |= (linked_list->data.address64.decode & 0x01) << 1;
-	temp8 |= (linked_list->data.address64.min_address_fixed & 0x01) << 2;
-	temp8 |= (linked_list->data.address64.max_address_fixed & 0x01) << 3;
-
-	*buffer = temp8;
+	*buffer = acpi_rs_encode_general_flags(&linked_list->data);
 	buffer += 1;
 
 	/* Set the type specific flags */
 
-	temp8 = 0;
-
-	if (ACPI_MEMORY_RANGE == linked_list->data.address64.resource_type) {
-		temp8 = (u8)
-		    (linked_list->data.address64.attribute.memory.
-		     read_write_attribute & 0x01);
-
-		temp8 |=
-		    (linked_list->data.address64.attribute.memory.
-		     cache_attribute & 0x03) << 1;
-	} else if (ACPI_IO_RANGE == linked_list->data.address64.resource_type) {
-		temp8 = (u8)
-		    (linked_list->data.address64.attribute.io.range_attribute &
-		     0x03);
-		temp8 |=
-		    (linked_list->data.address64.attribute.io.range_attribute &
-		     0x03) << 4;
-	}
-
-	*buffer = temp8;
+	*buffer = acpi_rs_encode_specific_flags(&linked_list->data);
 	buffer += 1;
 
 	/* Set the address space granularity */
@@ -1109,22 +1084,19 @@
 
 	/* Resource Source Index and Resource Source are optional */
 
-	if (0 != linked_list->data.address64.resource_source.string_length) {
-		temp8 = (u8) linked_list->data.address64.resource_source.index;
-
-		*buffer = temp8;
+	if (linked_list->data.address64.resource_source.string_length) {
+		*buffer =
+		    (u8) linked_list->data.address64.resource_source.index;
 		buffer += 1;
 
-		temp_pointer = (char *)buffer;
-
-		/* Copy the string */
+		/* Copy the resource_source string */
 
-		ACPI_STRCPY(temp_pointer,
+		ACPI_STRCPY((char *)buffer,
 			    linked_list->data.address64.resource_source.
 			    string_ptr);
 
 		/*
-		 * Buffer needs to be set to the length of the sting + one for the
+		 * Buffer needs to be set to the length of the string + one for the
 		 * terminating null
 		 */
 		buffer +=
diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/resources/rsirq.c acpica-unix-20050902/drivers/acpi/resources/rsirq.c
--- acpica-unix-20050815/drivers/acpi/resources/rsirq.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/resources/rsirq.c	2005-09-02 23:37:11.000000000 -0400
@@ -290,7 +290,7 @@
 
 	ACPI_FUNCTION_TRACE("rs_extended_irq_resource");
 
-	/* Point past the Descriptor to get the number of bytes consumed */
+	/* Get the Descriptor Length field */
 
 	buffer += 1;
 	ACPI_MOVE_16_TO_16(&temp16, buffer);
@@ -398,7 +398,7 @@
 		/* Copy the string into the buffer */
 
 		index = 0;
-		while (0x00 != *buffer) {
+		while (*buffer) {
 			*temp_ptr = *buffer;
 
 			temp_ptr += 1;
@@ -408,7 +408,7 @@
 
 		/* Add the terminating null */
 
-		*temp_ptr = 0x00;
+		*temp_ptr = 0;
 		output_struct->data.extended_irq.resource_source.string_length =
 		    index + 1;
 
@@ -420,7 +420,7 @@
 		temp8 = (u8) (index + 1);
 		struct_size += ACPI_ROUND_UP_to_32_bITS(temp8);
 	} else {
-		output_struct->data.extended_irq.resource_source.index = 0x00;
+		output_struct->data.extended_irq.resource_source.index = 0;
 		output_struct->data.extended_irq.resource_source.string_length =
 		    0;
 		output_struct->data.extended_irq.resource_source.string_ptr =
@@ -461,16 +461,15 @@
 	u16 *length_field;
 	u8 temp8 = 0;
 	u8 index;
-	char *temp_pointer = NULL;
 
 	ACPI_FUNCTION_TRACE("rs_extended_irq_stream");
 
-	/* The descriptor field is static */
+	/* Set the Descriptor Type field */
 
-	*buffer = 0x89;
+	*buffer = ACPI_RDESC_TYPE_EXTENDED_XRUPT;
 	buffer += 1;
 
-	/* Set a pointer to the Length field - to be filled in later */
+	/* Save a pointer to the Length field - to be filled in later */
 
 	length_field = ACPI_CAST_PTR(u16, buffer);
 	buffer += 2;
@@ -524,16 +523,14 @@
 		    (u8) linked_list->data.extended_irq.resource_source.index;
 		buffer += 1;
 
-		temp_pointer = (char *)buffer;
-
 		/* Copy the string */
 
-		ACPI_STRCPY(temp_pointer,
+		ACPI_STRCPY((char *)buffer,
 			    linked_list->data.extended_irq.resource_source.
 			    string_ptr);
 
 		/*
-		 * Buffer needs to be set to the length of the sting + one for the
+		 * Buffer needs to be set to the length of the string + one for the
 		 * terminating null
 		 */
 		buffer +=
diff -u -r -x '*~' acpica-unix-20050815/drivers/acpi/utilities/utmisc.c acpica-unix-20050902/drivers/acpi/utilities/utmisc.c
--- acpica-unix-20050815/drivers/acpi/utilities/utmisc.c	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/drivers/acpi/utilities/utmisc.c	2005-09-02 23:37:11.000000000 -0400
@@ -67,6 +67,14 @@
 
 	ACPI_FUNCTION_TRACE("ut_allocate_owner_id");
 
+	/* Guard against multiple allocations of ID to the same location */
+
+	if (*owner_id) {
+		ACPI_REPORT_ERROR(("Owner ID [%2.2X] already exists\n",
+				   *owner_id));
+		return_ACPI_STATUS(AE_ALREADY_EXISTS);
+	}
+
 	/* Mutex for the global ID mask */
 
 	status = acpi_ut_acquire_mutex(ACPI_MTX_CACHES);
@@ -80,7 +88,8 @@
 		if (!(acpi_gbl_owner_id_mask & (1 << i))) {
 			ACPI_DEBUG_PRINT((ACPI_DB_VALUES,
 					  "Current owner_id mask: %8.8X New ID: %2.2X\n",
-					  acpi_gbl_owner_id_mask, (i + 1)));
+					  acpi_gbl_owner_id_mask,
+					  (unsigned int)(i + 1)));
 
 			acpi_gbl_owner_id_mask |= (1 << i);
 			*owner_id = (acpi_owner_id) (i + 1);
@@ -143,7 +152,9 @@
 		return_VOID;
 	}
 
-	owner_id--;		/* Normalize to zero */
+	/* Normalize the ID to zero */
+
+	owner_id--;
 
 	/* Free the owner ID only if it is valid */
 
diff -u -r -x '*~' acpica-unix-20050815/include/acpi/acconfig.h acpica-unix-20050902/include/acpi/acconfig.h
--- acpica-unix-20050815/include/acpi/acconfig.h	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/include/acpi/acconfig.h	2005-09-02 23:37:11.000000000 -0400
@@ -63,7 +63,7 @@
 
 /* Version string */
 
-#define ACPI_CA_VERSION                 0x20050815
+#define ACPI_CA_VERSION                 0x20050902
 
 /*
  * OS name, used for the _OS object.  The _OS object is essentially obsolete,
diff -u -r -x '*~' acpica-unix-20050815/include/acpi/acdispat.h acpica-unix-20050902/include/acpi/acdispat.h
--- acpica-unix-20050815/include/acpi/acdispat.h	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/include/acpi/acdispat.h	2005-09-02 23:37:11.000000000 -0400
@@ -194,8 +194,7 @@
 acpi_ds_restart_control_method(struct acpi_walk_state *walk_state,
 			       union acpi_operand_object *return_desc);
 
-acpi_status
-acpi_ds_terminate_control_method(struct acpi_walk_state *walk_state);
+void acpi_ds_terminate_control_method(struct acpi_walk_state *walk_state);
 
 acpi_status
 acpi_ds_begin_method_execution(struct acpi_namespace_node *method_node,
diff -u -r -x '*~' acpica-unix-20050815/include/acpi/actypes.h acpica-unix-20050902/include/acpi/actypes.h
--- acpica-unix-20050815/include/acpi/actypes.h	2005-08-29 23:13:36.000000000 -0400
+++ acpica-unix-20050902/include/acpi/actypes.h	2005-09-02 23:37:11.000000000 -0400
@@ -1074,14 +1074,21 @@
 	char *string_ptr;
 };
 
+/* Fields common to all address descriptors, 16/32/64 bit */
+
+#define ACPI_RESOURCE_ADDRESS_COMMON \
+	u32                                 resource_type; \
+	u32                                 producer_consumer; \
+	u32                                 decode; \
+	u32                                 min_address_fixed; \
+	u32                                 max_address_fixed; \
+	union acpi_resource_attribute       attribute;
+
+struct acpi_resource_address {
+ACPI_RESOURCE_ADDRESS_COMMON};
+
 struct acpi_resource_address16 {
-	u32 resource_type;
-	u32 producer_consumer;
-	u32 decode;
-	u32 min_address_fixed;
-	u32 max_address_fixed;
-	union acpi_resource_attribute attribute;
-	u32 granularity;
+	ACPI_RESOURCE_ADDRESS_COMMON u32 granularity;
 	u32 min_address_range;
 	u32 max_address_range;
 	u32 address_translation_offset;
@@ -1090,13 +1097,7 @@
 };
 
 struct acpi_resource_address32 {
-	u32 resource_type;
-	u32 producer_consumer;
-	u32 decode;
-	u32 min_address_fixed;
-	u32 max_address_fixed;
-	union acpi_resource_attribute attribute;
-	u32 granularity;
+	ACPI_RESOURCE_ADDRESS_COMMON u32 granularity;
 	u32 min_address_range;
 	u32 max_address_range;
 	u32 address_translation_offset;
@@ -1105,13 +1106,7 @@
 };
 
 struct acpi_resource_address64 {
-	u32 resource_type;
-	u32 producer_consumer;
-	u32 decode;
-	u32 min_address_fixed;
-	u32 max_address_fixed;
-	union acpi_resource_attribute attribute;
-	u64 granularity;
+	ACPI_RESOURCE_ADDRESS_COMMON u64 granularity;
 	u64 min_address_range;
 	u64 max_address_range;
 	u64 address_translation_offset;
@@ -1161,6 +1156,7 @@
 	struct acpi_resource_mem24 memory24;
 	struct acpi_resource_mem32 memory32;
 	struct acpi_resource_fixed_mem32 fixed_memory32;
+	struct acpi_resource_address address;	/* Common 16/32/64 address fields */
 	struct acpi_resource_address16 address16;
 	struct acpi_resource_address32 address32;
 	struct acpi_resource_address64 address64;
